# Qiskit Quantum Inspire

[![License](https://img.shields.io/github/license/qutech-delft/qiskit-quantuminspire.svg?style=popout-square)](https://opensource.org/licenses/Apache-2.0)

**Qiskit** is an open-source SDK for working with quantum computers at the level of circuits, algorithms, and application modules.

This project contains a provider that allows access to **[Quantum Inspire]** quantum systems.

## Getting started

All information needed to get started using this plugin can be found in our [documentation](https://qutech-delft.github.io/qiskit-quantuminspire/). Some particularly useful links:

1. [Installation and login](https://qutech-delft.github.io/qiskit-quantuminspire/getting_started/installation.html)
2. [Submitting your first circuit](https://qutech-delft.github.io/qiskit-quantuminspire/getting_started/submitting.html)
3. [Example notebooks](https://qutech-delft.github.io/qiskit-quantuminspire/notebooks/index.html)

[quantum inspire]: https://www.quantum-inspire.com/
